import { MystiqueManifestFragment } from 'mystique/types/manifest';

export const manifest: MystiqueManifestFragment = {
  manifestVersion: '2.0',
  routes: [
    {
      type: 'section',
      nav: {
        label: 'Standalone Features',
        icon: 'insert_chart',
      },
      pages: [
        {
          type: 'page',
          path: 'feature/AddEditCustomerAddress',
          component: 'fc.page',
          nav: {
            label: 'Add and Edit Customer Address',
            icon: 'face',
          },
          props: {
            title: 'Add and Edit Customer Address Action Showcase',
            actions: {
              secondary: [
                {
                  type: 'mutation',
                  label:
                    'Add Customer Address',
                  name: 'createCustomerAddress',
                  condition: '{{eq customerAddresses.edges.length 0}}',
                  filter: {
                    type: 'exclude',
                    names: ['latitude', 'longitude'],
                  },
                  overrides: {
                    ref: {
                      sortPrefix: 11,
                    },
                    companyName: {
                      sortPrefix: 12,
                    },
                    street: {
                      sortPrefix: 13,
                    },
                    city: {
                      sortPrefix: 14,
                    },
                    state: {
                      sortPrefix: 15,
                    },
                    postcode: {
                      sortPrefix: 16,
                    },
                    region: {
                      sortPrefix: 17,
                    },
                    country: {
                      sortPrefix: 18,
                      component: 'settingBaseStringSelector',
                      extensions: {
                        settingName: 'EDIT_LOCATION_COUNTRIES',
                      },
                    },
                    timeZone: {
                      sortPrefix: 19,
                      component: 'settingBaseStringSelector',
                      extensions: {
                        settingName: 'EDIT_LOCATION_TIME_ZONES',
                      },
                    },
                    name: {
                      component: 'input',
                      sortPrefix: 20,
                      options: [
                        {
                          label: 'Customer Name',
                          value:
                            '{{customerById.firstName}} {{customerById.lastName}}',
                        },
                      ],
                    },
                  },
                },
                {
                  type: 'mutation',
                  label:
                    'Edit Customer Address',
                  name: 'updateCustomerAddress',
                  condition: '{{gt customerAddresses.edges.length 0}}',
                  filter: {
                    type: 'exclude',
                    names: ['name', 'latitude', 'longitude'],
                  },
                  args: {
                    id: '{{customerAddresses.edges.0.node.id}}',
                  },
                  overrides: {
                    companyName: {
                      sortPrefix: 12,
                    },
                    street: {
                      sortPrefix: 13,
                    },
                    city: {
                      sortPrefix: 14,
                    },
                    state: {
                      sortPrefix: 15,
                    },
                    postcode: {
                      sortPrefix: 16,
                    },
                    region: {
                      sortPrefix: 17,
                    },
                    country: {
                      sortPrefix: 18,
                      component: 'settingBaseStringSelector',
                      extensions: {
                        settingName: 'EDIT_LOCATION_COUNTRIES',
                      },
                    },
                    timeZone: {
                      sortPrefix: 19,
                      component: 'settingBaseStringSelector',
                      extensions: {
                        settingName: 'EDIT_LOCATION_TIME_ZONES',
                      },
                    },
                    name: {
                      component: 'input',
                      sortPrefix: 20,
                      options: [
                        {
                          label: 'Customer Name',
                          value:
                            '{{customerById.firstName}} {{customerById.lastName}}',
                        },
                      ],
                    },
                  },
                }
              ],
            },
          },
        },
      ],
    },
  ],
};
